# Triple

[![Build Status](https://img.shields.io/pypi/v/triple)](https://pypi.python.org/pypi/triple)
[![Downloads](https://pepy.tech/badge/triple)](https://pypi.python.org/pypi/triple)
[![Python Version](https://img.shields.io/pypi/pyversions/triple)](https://pypi.python.org/pypi/triple)
[![License](https://img.shields.io/pypi/l/triple)](https://pypi.python.org/pypi/triple)


Triple Server Agent.

**How to use**

After Installation Open Terminal(MAC, Linux), Command Prompt(Windows) and type : 

```
$ triple -s
```
**GOOD LUCK**

